"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAuthOptions = exports.EncryptionAlgorithms = exports.jwtAuth = void 0;
var tslib_1 = require("tslib");
var http_errors_1 = tslib_1.__importDefault(require("http-errors"));
var jsonwebtoken_1 = tslib_1.__importStar(require("jsonwebtoken"));
var getTokenFromAuthHeader_1 = require("./helpers/getTokenFromAuthHeader");
var getTokenFromSource_1 = require("./helpers/getTokenFromSource");
var AuthOptions_1 = require("./interfaces/AuthOptions");
Object.defineProperty(exports, "EncryptionAlgorithms", { enumerable: true, get: function () { return AuthOptions_1.EncryptionAlgorithms; } });
Object.defineProperty(exports, "isAuthOptions", { enumerable: true, get: function () { return AuthOptions_1.isAuthOptions; } });
var logger_1 = require("./logger");
exports.jwtAuth = function (options) {
    if (!AuthOptions_1.isAuthOptions(options)) {
        throw new TypeError("Expected AuthOptions, received " + JSON.stringify(options) + " instead");
    }
    return function (handler) { return function (event, context) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var token, payload, auth;
        var _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    if (event.auth !== undefined) {
                        logger_1.logger("event.auth already populated, has to be empty");
                        throw http_errors_1.default(400, "The events auth property has to be empty", {
                            type: "EventAuthNotEmpty",
                        });
                    }
                    token = (_a = getTokenFromSource_1.getTokenFromSource(event, options.tokenSource)) !== null && _a !== void 0 ? _a : getTokenFromAuthHeader_1.getTokenFromAuthHeader(event);
                    if (!(token === undefined)) return [3 /*break*/, 2];
                    logger_1.logger("No authorization header found");
                    if (options.credentialsRequired) {
                        throw http_errors_1.default(401, "No valid bearer token was set in the authorization header", {
                            type: "AuthenticationRequired",
                        });
                    }
                    return [4 /*yield*/, handler(event, context)];
                case 1: return [2 /*return*/, _b.sent()];
                case 2:
                    logger_1.logger("Verifying authorization token");
                    try {
                        jsonwebtoken_1.default.verify(token, options.secretOrPublicKey, {
                            algorithms: [options.algorithm],
                        });
                        logger_1.logger("Token verified");
                    }
                    catch (err) {
                        logger_1.logger("Token could not be verified");
                        if (err instanceof jsonwebtoken_1.TokenExpiredError) {
                            logger_1.logger("Token expired at " + new Date(err.expiredAt).toUTCString());
                            throw http_errors_1.default(401, "Token expired at " + new Date(err.expiredAt).toUTCString(), {
                                expiredAt: err.expiredAt,
                                type: "TokenExpiredError",
                            });
                        }
                        if (err instanceof jsonwebtoken_1.NotBeforeError) {
                            logger_1.logger("Token not valid before " + err.date);
                            throw http_errors_1.default(401, "Token not valid before " + err.date, {
                                date: err.date,
                                type: "NotBeforeError",
                            });
                        }
                        throw http_errors_1.default(401, "Invalid token", {
                            type: "InvalidToken",
                        });
                    }
                    payload = jsonwebtoken_1.default.decode(token);
                    if (options.isPayload !== undefined) {
                        logger_1.logger("Verifying token payload");
                        if (!options.isPayload(payload)) {
                            logger_1.logger("Token payload malformed, was " + JSON.stringify(payload));
                            throw http_errors_1.default(400, "Token payload malformed, was " + JSON.stringify(payload), {
                                payload: payload,
                                type: "TokenPayloadMalformedError",
                            });
                        }
                        logger_1.logger("Token payload valid");
                    }
                    auth = {
                        payload: jsonwebtoken_1.default.decode(token),
                        token: token,
                    };
                    return [4 /*yield*/, handler(tslib_1.__assign(tslib_1.__assign({}, event), { auth: auth }), context)];
                case 3: return [2 /*return*/, _b.sent()];
            }
        });
    }); }; };
};
var AuthorizedEvent_1 = require("./interfaces/AuthorizedEvent");
Object.defineProperty(exports, "isAuthorizedEvent", { enumerable: true, get: function () { return AuthorizedEvent_1.isAuthorizedEvent; } });
//# sourceMappingURL=jwtAuth.js.map